@@ -11,10 +11,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 """IloClient module"""
 
 import collections
+
 import netaddr
+
 from proliantutils import exception
 from proliantutils.ilo import ipmi
 from proliantutils.ilo import operations
@@ -24,6 +27,7 @@ from proliantutils.ilo.snmp import snmp_cpqdisk_sizes as snmp
 from proliantutils import log
 from proliantutils.redfish import redfish
 
+
 SUPPORTED_RIS_METHODS = [
     'activate_license',
     'clear_secure_boot_keys',
@@ -69,12 +73,13 @@ SUPPORTED_RIS_METHODS = [
     'set_vm_status',
     'update_firmware',
     'update_persistent_boot',
-    ]
+]
 
 SUPPORTED_REDFISH_METHODS = [
     'create_raid_configuration',
     'delete_raid_configuration',
     'do_disk_erase',
+    'do_one_button_secure_erase',
     'has_disk_erase_completed',
     'get_product_name',
     'get_host_post_state',
@@ -115,7 +120,11 @@ SUPPORTED_REDFISH_METHODS = [
     'set_iscsi_info',
     'unset_iscsi_info',
     'get_iscsi_initiator_info',
-    'set_iscsi_initiator_info'
+    'set_iscsi_initiator_info',
+    'set_http_boot_url',
+    'get_http_boot_url',
+    'add_tls_certificate',
+    'remove_tls_certificate'
 ]
 
 LOG = log.get_logger(__name__)
@@ -866,6 +875,20 @@ class IloClient(operations.IloOperations):
         """
         return self._call_method('do_disk_erase', disk_type, pattern)
 
+    def do_one_button_secure_erase(self):
+        """Perform the one button secure erase on the hardware.
+
+        The One-button secure erase process resets iLO and deletes all licenses
+        stored there, resets BIOS settings, and deletes all AHS and warranty
+        data stored on the system. It also erases supported non-volatile
+        storage data and deletes any deployment settings profiles.
+
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is
+                 not supported on the server.
+        """
+        return self._call_method('do_one_button_secure_erase')
+
     def get_available_disk_types(self):
         """Get the list of all disk type available in server
 
@@ -873,3 +896,19 @@ class IloClient(operations.IloOperations):
         :raises: IloError, on an error from iLO.
         """
         return self._call_method('get_available_disk_types')
+
+    def add_tls_certificate(self, cert_file_list):
+        """Adds the TLS certificate to the iLO
+
+        :param cert_file_list: List of TLS certificate files
+        :raises: IloError, on an error from iLO.
+        """
+        return self._call_method('add_tls_certificate', cert_file_list)
+
+    def remove_tls_certificate(self, cert_file_list):
+        """Removes the TLS certificate from the iLO
+
+        :param cert_file_list: List of TLS certificate files
+        :raises: IloError, on an error from iLO.
+        """
+        return self._call_method('remove_tls_certificate', cert_file_list)
