@@ -14,8 +14,12 @@
 
 __author__ = 'HPE'
 
+from base64 import b64decode
 import json
+import re
 
+from OpenSSL.crypto import FILETYPE_ASN1
+from OpenSSL.crypto import load_certificate
 from six.moves.urllib import parse
 import sushy
 from sushy.resources.system import mappings as sushy_map
@@ -55,6 +59,7 @@ DEVICE_COMMON_TO_REDFISH = {
     'HDD': sushy.BOOT_SOURCE_TARGET_HDD,
     'CDROM': sushy.BOOT_SOURCE_TARGET_CD,
     'ISCSI': sushy.BOOT_SOURCE_TARGET_UEFI_TARGET,
+    'UEFIHTTP': sushy.BOOT_SOURCE_TARGET_UEFI_HTTP,
     'NONE': sushy.BOOT_SOURCE_TARGET_NONE
 }
 
@@ -73,6 +78,7 @@ PERSISTENT_BOOT_MAP = {
     sushy.BOOT_SOURCE_TARGET_HDD: 'HDD',
     sushy.BOOT_SOURCE_TARGET_CD: 'CDROM',
     sushy.BOOT_SOURCE_TARGET_UEFI_TARGET: 'NETWORK',
+    sushy.BOOT_SOURCE_TARGET_UEFI_HTTP: 'UEFIHTTP',
     sushy.BOOT_SOURCE_TARGET_NONE: 'NONE'
 }
 
@@ -111,6 +117,9 @@ SUPPORTED_BOOT_MODE_MAP = {
         ilo_cons.SUPPORTED_BOOT_MODE_LEGACY_BIOS_AND_UEFI)
 }
 
+_CERTIFICATE_PATTERN = (
+    r'-----BEGIN CERTIFICATE-----.*?-----END CERTIFICATE-----')
+
 LOG = log.get_logger(__name__)
 
 
@@ -568,7 +577,7 @@ class RedfishOperations(operations.IloOperations):
         for item in devices:
             if item.upper() not in DEVICE_COMMON_TO_REDFISH:
                 msg = (self._('Invalid input "%(device)s". Valid devices: '
-                              'NETWORK, HDD, ISCSI or CDROM.') %
+                              'NETWORK, HDD, ISCSI, UEFIHTTP or CDROM.') %
                        {'device': item})
                 raise exception.IloInvalidInputError(msg)
 
@@ -594,7 +603,7 @@ class RedfishOperations(operations.IloOperations):
         # Check if the input is valid
         if device.upper() not in DEVICE_COMMON_TO_REDFISH:
             msg = (self._('Invalid input "%(device)s". Valid devices: '
-                          'NETWORK, HDD, ISCSI or CDROM.') %
+                          'NETWORK, HDD, ISCSI, UEFIHTTP or CDROM.') %
                    {'device': device})
             raise exception.IloInvalidInputError(msg)
 
@@ -651,6 +660,72 @@ class RedfishOperations(operations.IloOperations):
             LOG.debug(msg)
             raise exception.IloError(msg)
 
+    def _get_security_dashboard_values(self):
+        """Gets all the parameters related to security dashboard.
+
+        :return: a dictionary of the security dashboard values
+                 with their security status and security parameters
+                 with their complete details and security status.
+        :raises: IloError, if security dashboard or their params
+            not found or on an error from iLO.
+        """
+        sec_capabilities = {}
+        sushy_manager = self._get_sushy_manager(PROLIANT_MANAGER_ID)
+        try:
+
+            security_dashboard = (
+                sushy_manager.securityservice.securitydashboard)
+            security_params = (
+                sushy_manager.securityservice.securityparamscollectionuri)
+            sec_capabilities.update(
+                {'server_configuration_lock_status': (
+                 security_dashboard.server_configuration_lock_status),
+                 'overall_security_status': (
+                 security_dashboard.overall_status)})
+            security_parameters = {}
+            param_members = security_params.get_members()
+            for param in param_members:
+                param_dict = {param.name: {'security_status': param.status,
+                                           'state': param.state,
+                                           'ignore': param.ignore}}
+                if param.description:
+                    param_dict[param.name].update(
+                        {'description': param.description})
+                if param.recommended_action:
+                    param_dict[param.name].update(
+                        {'recommended_action': param.recommended_action})
+                security_parameters.update(param_dict)
+            sec_capabilities.update(
+                {'security_parameters': security_parameters})
+        except sushy.exceptions.SushyError as e:
+            msg = (self._("The Redfish controller is unable to get "
+                          "resource or its members. Error "
+                          "%(error)s)") % {'error': str(e)})
+            LOG.debug(msg)
+            raise exception.IloError(msg)
+
+        return sec_capabilities
+
+    def _parse_security_dashboard_values_for_capabilities(self):
+        """Parses the security dashboard parameters.
+
+        :returns: a dictionary of only those security parameters and their
+            security status which are applicable for ironic.
+        """
+        values = self._get_security_dashboard_values()
+        ironic_sec_capabilities = {}
+        ironic_sec_capabilities.update(
+            {'overall_security_status': values.get('overall_security_status')})
+        param_values = values.get('security_parameters')
+        p_map = {'Last Firmware Scan Result': 'last_firmware_scan_result',
+                 'Security Override Switch': 'security_override_switch'}
+        p_keys = p_map.keys()
+        for p_key, p_val in param_values.items():
+            if p_key in p_keys:
+                p_dict = {p_map.get(p_key): p_val.get('security_status')}
+                ironic_sec_capabilities.update(p_dict)
+        return ironic_sec_capabilities
+
     def get_server_capabilities(self):
         """Returns the server capabilities
 
@@ -696,7 +771,7 @@ class RedfishOperations(operations.IloOperations):
                  common_storage.has_rotational(sushy_system)),
                 ('has_nvme_ssd',
                  common_storage.has_nvme_ssd(sushy_system))
-                ]
+            ]
 
             all_key_to_value_expression_tuples += (
                 [('logical_raid_level_' + x, True)
@@ -723,6 +798,9 @@ class RedfishOperations(operations.IloOperations):
                      'logical_nvdimm_n': (
                      json.dumps(memory_data.has_logical_nvdimm_n))})
 
+            capabilities.update(
+                self._parse_security_dashboard_values_for_capabilities())
+
         except sushy.exceptions.SushyError as e:
             msg = (self._("The Redfish controller is unable to get "
                           "resource or its members. Error "
@@ -1112,6 +1190,19 @@ class RedfishOperations(operations.IloOperations):
         sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
         return sushy_system.has_disk_erase_completed()
 
+    def do_one_button_secure_erase(self):
+        """Perform the one button secure erase on the hardware.
+
+        The One-button secure erase process resets iLO and deletes all licenses
+        stored there, resets BIOS settings, and deletes all AHS and warranty
+        data stored on the system. It also erases supported non-volatile
+        storage data and deletes any deployment settings profiles.
+
+        :raises: IloError, on an error from iLO.
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        sushy_system.do_one_button_secure_erase()
+
     def get_current_bios_settings(self, only_allowed_settings=False):
         """Get current BIOS settings.
 
@@ -1276,3 +1367,170 @@ class RedfishOperations(operations.IloOperations):
         """
         sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
         return sushy_system.get_disk_types()
+
+    def get_http_boot_url(self):
+        """Sets current BIOS settings to the provided data.
+
+        :raises: IloError, on an error from iLO.
+        :return: Returns the setting 'UrlBootFile' if set previously.
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        url = None
+        try:
+            settings = sushy_system.bios_settings.json
+            attributes = settings.get('Attributes')
+            url = attributes.get('UrlBootFile')
+        except sushy.exceptions.SushyError as e:
+            msg = (self._('The attribute "UrlBootFile" not found.'
+                          ' Error %(error)s') %
+                   {'error': str(e)})
+            LOG.debug(msg)
+            raise exception.IloError(msg)
+        return url
+
+    def set_http_boot_url(self, url, is_dhcp_enabled=True):
+        """Sets HTTP boot URL to boot from it.
+
+        :param: url: HTTP URL of the image to be booted on the iLO.
+        :param: is_dhcp_enabled: True if no static IP is set on the node and
+                preferred to use DHCP service running in the network.
+                If False, the MAC is expected to be configured with static IP.
+        :raises: IloError, on an error from iLO.
+        """
+        if not url:
+            raise exception.IloError("Could not set http url with"
+                                     " empty URL")
+        data = {
+            'PreBootNetwork': 'Auto',
+            'UrlBootFile': url,
+            'Dhcpv4': 'Enabled' if is_dhcp_enabled else 'Disabled'
+        }
+
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+        try:
+            settings_required = sushy_system.bios_settings.pending_settings
+            settings_required.update_bios_data_by_post(data)
+        except sushy.exceptions.SushyError as e:
+            msg = (self._('Could not set HTTPS URL on the iLO.'
+                          ' Error %(error)s') %
+                   {'error': str(e)})
+            LOG.debug(msg)
+            raise exception.IloError(msg)
+
+    def add_tls_certificate(self, cert_file_list):
+        """Adds the TLS certificates to the iLO.
+
+        :param cert_file_list: List of TLS certificate files
+
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is
+                 not supported on the server.
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+
+        if(self._is_boot_mode_uefi()):
+            cert_list = []
+            for cert_file in cert_file_list:
+                with open(cert_file, 'r') as f:
+                    data = json.dumps(f.read())
+                p = re.sub(r"\"", "", data)
+                q = re.sub(r"\\n", "\r\n", p).rstrip()
+
+                c_list = re.findall(_CERTIFICATE_PATTERN, q, re.DOTALL)
+
+                if len(c_list) == 0:
+                    LOG.warning("Could not find any valid certificate in "
+                                "%(cert_file)s. Ignoring." %
+                                {"cert_file": cert_file})
+                    continue
+
+                for content in c_list:
+                    cert = {}
+                    cert['X509Certificate'] = content
+                    cert_list.append(cert)
+
+            if len(cert_list) == 0:
+                msg = (self._("No valid certificate in %(cert_file_list)s.") %
+                       {"cert_file_list": cert_file_list})
+                LOG.debug(msg)
+                raise exception.IloError(msg)
+
+            cert_dict = {}
+            cert_dict['NewCertificates'] = cert_list
+            try:
+                (sushy_system.bios_settings.tls_config.
+                 tls_config_settings.add_tls_certificate(cert_dict))
+            except sushy.exceptions.SushyError as e:
+                msg = (self._("The Redfish controller has failed to upload "
+                              "TLS certificate. Error %(error)s") %
+                       {'error': str(e)})
+                LOG.debug(msg)
+                raise exception.IloError(msg)
+        else:
+            msg = 'TLS certificate cannot be upload in BIOS boot mode'
+            raise exception.IloCommandNotSupportedInBiosError(msg)
+
+    def remove_tls_certificate(self, cert_file_list):
+        """Removes the TLS certificate from the iLO.
+
+        :param cert_file_list: List of TLS certificate files
+
+        :raises: IloError, on an error from iLO.
+        :raises: IloCommandNotSupportedError, if the command is
+                 not supported on the server.
+        """
+        sushy_system = self._get_sushy_system(PROLIANT_SYSTEM_ID)
+
+        if(self._is_boot_mode_uefi()):
+            cert_dict = {}
+            del_cert_list = []
+            for cert_file in cert_file_list:
+                with open(cert_file, 'r') as f:
+                    data = json.dumps(f.read())
+                    p = re.sub(r"\"", "", data)
+                    q = re.sub(r"\\n", "\r\n", p).rstrip()
+
+                    c_list = re.findall(_CERTIFICATE_PATTERN, q, re.DOTALL)
+
+                    if len(c_list) == 0:
+                        LOG.warning("Could not find any valid certificate in "
+                                    "%(cert_file)s. Ignoring." %
+                                    {"cert_file": cert_file})
+                        continue
+
+                    for content in c_list:
+                        pem_lines = [line.strip() for line in (
+                            content.strip().split('\n'))]
+
+                        try:
+                            der_data = b64decode(''.join(pem_lines[1:-1]))
+                        except ValueError:
+                            LOG.warning("Illegal base64 encountered "
+                                        "in the certificate.")
+                        else:
+                            cert = load_certificate(FILETYPE_ASN1, der_data)
+                            fp = cert.digest('sha256').decode('ascii')
+                            cert_fp = {
+                                "FingerPrint": fp
+                            }
+                            del_cert_list.append(cert_fp)
+
+            if len(del_cert_list) == 0:
+                msg = (self._("No valid certificate in %(cert_file_list)s.") %
+                       {"cert_file_list": cert_file_list})
+                raise exception.IloError(msg)
+
+            cert_dict.update({"DeleteCertificates": del_cert_list})
+
+            try:
+                (sushy_system.bios_settings.tls_config.
+                 tls_config_settings.remove_tls_certificate(cert_dict))
+            except sushy.exceptions.SushyError as e:
+                msg = (self._("The Redfish controller has failed to remove "
+                              "TLS certificate. Error %(error)s") %
+                       {'error': str(e)})
+                LOG.debug(msg)
+                raise exception.IloError(msg)
+        else:
+            msg = 'TLS certificate cannot be removed in BIOS boot mode'
+            raise exception.IloCommandNotSupportedInBiosError(msg)
