@@ -2391,6 +2391,27 @@ Smart Array P440 in Slot 2
          Sanitize Estimated Max Erase Time: 0 hour(s)36 minute(s)
          Unrestricted Sanitize Supported: False
          Shingled Magnetic Recording Support: None
+
+      physicaldrive 6I:1:7
+         Port: 6I
+         Box: 1
+         Bay: 7
+         Status: OK
+         Drive Type: Unassigned Drive
+         Interface Type: Solid State SAS
+         Size: 200 GB
+         Native Block Size: 512
+         Rotational Speed: 15000
+         Firmware Revision: HPD6
+         Serial Number: 6SL7G54Q0000N4180W34
+         Model: HP      EF0600FARNA
+         Current Temperature (C): 31
+         Maximum Temperature (C): 39
+         PHY Count: 2
+         PHY Transfer Rate: 6.0Gbps, Unknown
+         Drive Authentication Status: OK
+         Carrier Application Version: 11
+         Carrier Bootloader Version: 6
 '''
 
 SSA_ERASE_IN_PROGRESS = '''
@@ -2507,3 +2528,62 @@ Smart Array P440 in Slot 2
          Sanitize Estimated Max Erase Time: 0 hour(s)36 minute(s)
          Unrestricted Sanitize Supported: False
 '''
+
+SSACLI_PARSING_TESTS = '''
+Smart HBA H240 in Slot 1 (RAID Mode)
+   Slot: 1
+   Controller Mode: RAID Mode
+
+   Internal Drive Cage at Port 1I, Box 1, OK
+      Drive Bays: 4
+      Port: 1I
+      Box: 1
+
+   Physical Drives
+      physicaldrive 1I:1:4 (port 1I:box 1:bay 4, SAS HDD, 900 GB, OK)
+      physicaldrive 1I:1:3 (port 1I:box 1:bay 3, SAS HDD, 900 GB, OK)
+
+   Internal Drive Cage at Port 2I, Box 1, OK
+      Drive Bays: 4
+      Port: 2I
+      Box: 1
+
+   Physical Drives
+      physicaldrive 2I:1:5 (port 2I:box 1:bay 5, SAS HDD, 900 GB, OK)
+      physicaldrive 2I:1:6 (port 2I:box 1:bay 6, SAS HDD, 900 GB, OK)
+
+   Unassigned
+      physicaldrive 1I:1:4
+         Port: 1I
+         Box: 1
+         Bay: 4
+         Size: 900 GB
+         Interface Type: SAS
+
+Smart HBA H240 in Slot 2 (RAID Mode)
+   Slot: 2
+   Controller Mode: RAID Mode
+   PCI Address (Domain:Bus:Device.Function): 0000:0B:00.0
+
+   Array: H
+      Interface Type: SAS
+
+      Logical Drive: 8
+         Size: 838.3 GB
+         Status: OK
+
+      physicaldrive 2I:2:8
+         Port: 2I
+         Box: 2
+         Bay: 8
+         Size: 900 GB
+         Interface Type: SAS
+
+Smart HBA H240 in Slot 3 (RAID Mode)
+   Slot: 3
+   Controller Mode: RAID Mode
+
+Smart HBA H240ar in Slot 0 (Embedded) (RAID Mode)
+   Bus Interface: PCI
+   Slot: 0
+'''
