@@ -344,13 +344,16 @@ class ControllerTest(testtools.TestCase):
                            get_all_details_mock):
         get_all_details_mock.return_value = raid_constants.SSA_ERASE_DRIVE
         server = objects.Server()
-        d = [x for x in server.controllers[0].unassigned_physical_drives]
+        drives = [x for x in server.controllers[0].unassigned_physical_drives]
         controller = server.controllers[0]
-        controller.erase_devices(d)
-        execute_mock.assert_called_once_with('pd 1I:2:1', 'modify', 'erase',
-                                             'erasepattern=overwrite',
-                                             'unrestricted=off',
-                                             'forced')
+        execute_mock.return_value = ""
+        controller.erase_devices(drives)
+        calls = [mock.call('pd 6I:1:7', 'modify', 'erase',
+                           'erasepattern=block', 'unrestricted=off', 'forced'),
+                 mock.call('pd 1I:2:1', 'modify', 'erase',
+                           'erasepattern=overwrite', 'unrestricted=off',
+                           'forced')]
+        execute_mock.assert_has_calls(calls, any_order=True)
 
     @mock.patch.object(objects.Controller, 'execute_cmd')
     def test_erase_devices_sanitize_not_supported(self, execute_mock,
@@ -606,6 +609,25 @@ class PhysicalDriveTest(testtools.TestCase):
         self.assertEqual('ready', ret['status'])
         self.assertEqual('OK', ret['erase_status'])
 
+    def test_ssacli_output_parsing(self, get_all_details_mock):
+
+        get_all_details_mock.return_value = raid_constants.SSACLI_PARSING_TESTS
+        server = objects.Server()
+        self.assertEqual(4, len(server.controllers))
+        id = 'Smart HBA H240ar in Slot 0 (Embedded) (RAID Mode)'
+        self.assertIsNotNone(server.get_controller_by_id(id))
+
+        id = 'Smart HBA H240 in Slot 2 (RAID Mode)'
+        controller = server.get_controller_by_id(id)
+        self.assertIsInstance(controller.properties, dict)
+        self.assertIn("PCI Address (Domain:Bus:Device.Function)",
+                      controller.properties)
+
+        id = 'Smart HBA H240 in Slot 1 (RAID Mode)'
+        controller = server.get_controller_by_id(id)
+        self.assertIsInstance(controller.properties, dict)
+        self.assertEqual(4, len(controller.properties['Physical Drives']))
+
 
 class PrivateMethodsTestCase(testtools.TestCase):
 
