@@ -25,6 +25,7 @@ import mock
 import requests
 from requests.packages import urllib3
 from requests.packages.urllib3 import exceptions as urllib3_exceptions
+import xmltodict
 
 from proliantutils import exception
 from proliantutils.ilo import common
@@ -102,6 +103,7 @@ class IloRibclTestCase(unittest.TestCase):
         self.ilo = ribcl.RIBCLOperations("x.x.x.x", "admin",
                                          "Admin", 60, 443)
         self.ilo.init_model_based_tags('ProLiant DL580 Gen8')
+        self.maxDiff = None
 
     def test_init_model_based_tags_gen7(self):
         self.ilo.init_model_based_tags('Proliant DL380 G7')
@@ -236,14 +238,14 @@ class IloRibclTestCase(unittest.TestCase):
         self.assertRaises(
             exception.IloCommandNotSupportedError,
             self.ilo.get_http_boot_url
-            )
+        )
 
     def test_set_http_boot_url(self):
         self.assertRaises(
             exception.IloCommandNotSupportedError,
             self.ilo.set_http_boot_url,
             'http://10.10.1.30:8081/startup.nsh'
-            )
+        )
 
     @mock.patch.object(ribcl.RIBCLOperations, '_request_ilo')
     def test_reset_server(self, request_ilo_mock):
@@ -818,7 +820,9 @@ class IloRibclTestCase(unittest.TestCase):
     def test_update_ilo_firmware(self, _parse_output_mock, _request_ilo_mock,
                                  os_mock, upload_file_to_mock):
         # | GIVEN |
-        upload_file_to_mock.return_value = 'hickory-dickory-dock'
+        # NOTE(mgoddard): Whitespace should be stripped from the cookie.
+        # https://launchpad.net/bugs/1859616.
+        upload_file_to_mock.return_value = ' hickory-dickory-dock'
         os_mock.path.getsize.return_value = 12345
         # | WHEN |
         self.ilo.update_firmware('raw_fw_file.bin', 'ilo')
@@ -826,15 +830,19 @@ class IloRibclTestCase(unittest.TestCase):
         upload_file_to_mock.assert_called_once_with(
             (self.ilo.host, self.ilo.port), self.ilo.timeout)
 
-        root_xml_string = constants.UPDATE_ILO_FIRMWARE_INPUT_XML % (
+        ref_root_xml_string = constants.UPDATE_ILO_FIRMWARE_INPUT_XML % (
             self.ilo.password, self.ilo.login, 12345, 'raw_fw_file.bin')
-        root_xml_string = re.sub('\n\s*', '', root_xml_string)
+        ref_root_xml_string = re.sub(r"\n\s*", '', ref_root_xml_string)
+        ref_dict = xmltodict.parse(ref_root_xml_string)
+        ref_string = json.dumps(ref_dict, sort_keys=True)
 
         ((ribcl_obj, xml_elem), the_ext_header_dict) = (
             _request_ilo_mock.call_args)
 
-        self.assertEqual(root_xml_string,
-                         ET.tostring(xml_elem).decode('latin-1'))
+        actual_dict = xmltodict.parse(ET.tostring(xml_elem).decode('latin-1'))
+        actual_string = json.dumps(actual_dict, sort_keys=True)
+        self.assertEqual(ref_string, actual_string)
+
         self.assertDictEqual(the_ext_header_dict['extra_headers'],
                              {'Cookie': 'hickory-dickory-dock'})
 
@@ -860,15 +868,19 @@ class IloRibclTestCase(unittest.TestCase):
         upload_file_to_mock.assert_called_once_with(
             (self.ilo.host, self.ilo.port), self.ilo.timeout)
 
-        root_xml_string = constants.UPDATE_NONILO_FIRMWARE_INPUT_XML % (
+        ref_root_xml_string = constants.UPDATE_NONILO_FIRMWARE_INPUT_XML % (
             self.ilo.password, self.ilo.login, 12345, 'raw_fw_file.bin')
-        root_xml_string = re.sub('\n\s*', '', root_xml_string)
+        ref_root_xml_string = re.sub(r"\n\s*", '', ref_root_xml_string)
+        ref_dict = xmltodict.parse(ref_root_xml_string)
+        ref_string = json.dumps(ref_dict, sort_keys=True)
 
         ((ribcl_obj, xml_elem), the_ext_header_dict) = (
             _request_ilo_mock.call_args)
 
-        self.assertEqual(root_xml_string,
-                         ET.tostring(xml_elem).decode('latin-1'))
+        actual_dict = xmltodict.parse(ET.tostring(xml_elem).decode('latin-1'))
+        actual_string = json.dumps(actual_dict, sort_keys=True)
+        self.assertEqual(ref_string, actual_string)
+
         self.assertDictEqual(the_ext_header_dict['extra_headers'],
                              {'Cookie': 'hickory-dickory-dock'})
 
@@ -1089,5 +1101,6 @@ class IloRibclTestCaseBeforeRisSupport(unittest.TestCase):
                                 'ProLiant DL380 G7',
                                 self.ilo.get_bios_settings_result)
 
+
 if __name__ == '__main__':
     unittest.main()
